@@ -468,23 +468,40 @@ REST_FRAMEWORK = {
 
 # django-project-backup
 SERIALIZATION_MODULES = {
-    'couchdb_datastore': 'django_project_backup.utils.couchdb.serializers'
+    'dbp_couchdb_datastore': 'django_project_backup.utils.couchdb.serializers'
 }
 
+DJANGO_PROJECT_BACKUP_MODE = env('DJANGO_PROJECT_BACKUP_MODE', default='incremental')
+
+DJANGO_PROJECT_BACKUP_REALTIME = env.bool('DJANGO_PROJECT_BACKUP_REALTIME', default=False)
+
 DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS = env.list('DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS', default=[
-    'sessions',
-    'admin',
-    'auth.permission',
-    'contenttypes',
+    'sessions.session',
+    'admin.logentry',
     'django_sso_app.passepartout',
     'django_sso_app.device'
 ])
 
-COUCHDB_DATASTORE_DATABASE_NAME = env('COUCHDB_DATASTORE_DATABASE_NAME', default='django_sso_app')
+DJANGO_PROJECT_BACKUP_PUBLIC_ASSETS_FOLDERS = env.list('DJANGO_PROJECT_BACKUP_PUBLIC_ASSETS_FOLDERS',
+                                                        default=[str(PUBLIC_ROOT)])
+
+DJANGO_PROJECT_BACKUP_PRIVATE_ASSETS_FOLDERS = env.list('DJANGO_PROJECT_BACKUP_PRIVATE_ASSETS_FOLDERS',
+                                                        default=[str(PRIVATE_ROOT)])
+
+DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER = env('DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER',
+                                               default=os.path.join(ROOT_DIR, 'backups'))
+
+DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_URL = env('DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_URL', default='http://127.0.0.1:5984')
+DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_USER = env('DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_USER', default='admin')
+DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_PASSWORD = env('DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_PASSWORD', default='couchdb')
+# couchdb db index
+DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_DATABASE_NAME = env('DJANGO_PROJECT_BACKUP_COUCHDB_DATASTORE_DATABASE_NAME',
+                                                            default='django_sso_app')
+
+DJANGO_PROJECT_BACKUP_DO_FAILSAFE_BACKUP = env.bool('DJANGO_PROJECT_BACKUP_DO_FAILSAFE_BACKUP',
+                                                    default=True)
+DJANGO_PROJECT_BACKUP_FAILSAFE_BACKUP_PATH = env('DJANGO_PROJECT_BACKUP_FAILSAFE_BACKUP_PATH',
+                                                 default=os.path.join(DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER, 'failed'))
 
-# django_couchdb_datastore settings
-COUCHDB_DATASTORE_HOST = env('COUCHDB_DATASTORE_HOST', default='http://127.0.0.1:5984')
-COUCHDB_DATASTORE_USER = env('COUCHDB_DATASTORE_USER', default='admin')
-COUCHDB_DATASTORE_PASSWORD = env('COUCHDB_DATASTORE_PASSWORD', default='couchdb')
 
 from .extra import *  # pai
