@@ -3,7 +3,7 @@ import logging
 import jwt
 
 from ...tokens.utils import jwt_decode, jwt_encode
-from ...utils import get_session_key, set_session_key, logger, set_cookie
+from ...utils import get_session_key, set_session_key, logger, set_cookie, get_random_fingerprint
 from ...tokens.utils import get_request_jwt
 from ...exceptions import RequestHasValidJwtWithNoDeviceAssociated
 from ... import app_settings
@@ -59,7 +59,7 @@ def get_or_create_request_device(request):
             raw_token = get_request_jwt(request)
 
             if raw_token is None:
-                fingerprint = 'undefined'
+                fingerprint = get_random_fingerprint(request)  # 'undefined'
             else:
                 try:
                     device, verified_payload = jwt_decode(raw_token, verify=True)
