@@ -31,10 +31,9 @@ from ...apps.emails.models import EmailAddress
 from ...permissions import StaffPermission
 from ...permissions import is_staff, is_django_staff
 from ...utils import invalidate_cookie, get_session_key
-from ..devices.utils import renew_response_jwt
+from ...views import DjangoSsoAppBaseViewMixin
 from ... import app_settings
 from .filters import UserFilter
-from ...views import DjangoSsoAppBaseViewMixin
 
 User = get_user_model()
 
@@ -183,6 +182,8 @@ class UserApiViewSet(mixins.ListModelMixin,
 
                 # must login again if password updated
                 if get_session_key(request, '__dssoa__user_password_updated', False):
+                    logger.info('User {0} updated password and must login again'.format(requesting_user))
+
                     invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
                 else:
                     self.update_response_jwt(user, response)
